
// Nascar Thunder Suspension File - Developed By Doug Arnao 07-06-02
// Notes: I have adjusted the mass & inertias of the body, spindle wheels, rear axle to closer match a stock car.
// Front Suspension Spec's:
// Roll center height = 3.14" with lower arm parallel to the ground
// There is -0.96 degree camber GAIN per 1" of bump travel
// Roll center moves linearly (more or less) with bump travel - IE if the chassis moves down 1 inch the RC moves down 1 inch
// With roll, the RC height doesn't move up or down any appreciable amount (1/8" max over 2 deg roll)
// With roll, the RC moves to the left (while turning left) .43" (11mm) per degree of roll
// For every degree of roll we LOSE +.64 deg of camber on the loaded side and GAIN -.69 on the onloaded side

//////////////////////////////////////////////////////////////////////////
//
// Conventions:
//
// +x = left
// +z = rear
// +y = up
// +pitch = nose up
// +yaw = nose right
// +roll = top right
//
// [BODY]  - a rigid mass with mass and inertial properties
// [JOINT] - a ball joint constraining an offset of one body to an
//           offset of another body (eliminates 3 DOF)
// [HINGE] - a constraint restricting the relative rotations of two
//           bodies to be around a single axis (eliminates 2 DOF).
// [BAR]   - a constraint holding an offset of one body from an offset of
//           another body at a fixed distance (eliminates 1 DOF).
// [JOINT&HINGE] - both the joint and hinge constraints, forming the
//           conventional definition of a hinge (eliminates 5 DOF).
//
//////////////////////////////////////////////////////////////////////////

// Body including all rigidly attached parts (wings, barge boards, etc.)
[BODY]
name=body mass=(1211.36) inertia=(1960.05,2168.85,370.27)
pos=(0.0,0.00,0.0) ori=(0.0,0.0,0.0)

// Front spindles
[BODY]
name=fl_spindle mass=(34.0) inertia=(0.132,0.121,0.110)
pos=(0.688,0.0,-1.34) ori=(0.0,0.0,0.0)

[BODY]
name=fr_spindle mass=(34.0) inertia=(0.132,0.121,0.110)
pos=(-0.688,0.0,-1.34) ori=(0.0,0.0,0.0)

// Front wheels
[BODY]
name=fl_wheel mass=(27.0) inertia=(1.425,0.943,0.943)
pos=(0.764,0.0,-1.34) ori=(0.0,0.0,0.0)

[BODY]
name=fr_wheel mass=(27.0) inertia=(1.425,0.943,0.943)
pos=(-0.764,0.0,-1.34) ori=(0.0,0.0,0.0)

// NASCAR stock car rear axle (this also contains the mass and inertia of the
// I-beams or torque tube because they are rigidly attached).
[BODY]
name=rear_axle mass=(131.82) inertia=(3.073,3.073,1.317)
pos=(0.0,-0.05,1.52) ori=(0.0,0.0,0.0)

// Rear wheels (includes half of rotating rear-axle)
[BODY]
name=rl_wheel mass=(36.36) inertia=(1.523,1.035,1.035)
pos=(0.688,0.0,1.62) ori=(0.0,0.0,0.0)

[BODY]
name=rr_wheel mass=(36.36) inertia=(1.523,1.035,1.035)
pos=(-0.688,0.0,1.62) ori=(0.0,0.0,0.0)

// Fuel in tank is not rigidly attached - attached with springs and dampers to simulate movement
[BODY]
name=fuel_tank mass=(1.0) inertia=(1.0,1.0,1.0)
pos=(0.0,0.00,1.92) ori=(0.0,0.0,0.0)


//////////////////////////////////////////////////////////////////////////
//
// Constraints
//
//////////////////////////////////////////////////////////////////////////


// Front wheel and spindle connections
[JOINT&HINGE]
posbody=fl_wheel negbody=fl_spindle pos=fl_wheel axis=(-1.0,0.0,0.0)

[JOINT&HINGE]
posbody=fr_wheel negbody=fr_spindle pos=fr_wheel axis=(1.0,0.0,0.0)

// Front left suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm
name=fl_fore_upper posbody=body negbody=fl_spindle pos=(0.406,0.195,-1.390) neg=(0.584,0.230,-1.340)

[BAR] // rearward upper arm
posbody=body negbody=fl_spindle pos=(0.406,0.180,-1.140) neg=(0.584,0.230,-1.340)

[BAR] // forward lower arm
posbody=body negbody=fl_spindle pos=(0.304,-0.148,-1.340) neg=(0.610,-0.148,-1.340)

[BAR] // rearward lower arm
name=fl_fore_lower posbody=body negbody=fl_spindle pos=(0.256,-0.130,-1.040) neg=(0.610,-0.148,-1.340)

[BAR] // steering arm (must be named for identification)
name=fl_steering posbody=body negbody=fl_spindle pos=(0.328,-0.106,-1.467) neg=(0.584,-0.100,-1.492)

// Front right suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm (used in steering lock calculation)
name=fr_fore_upper posbody=body negbody=fr_spindle pos=(-0.406,0.195,-1.390) neg=(-0.584,0.230,-1.340)

[BAR] // rearward upper arm
posbody=body negbody=fr_spindle pos=(-0.406,0.180,-1.140) neg=(-0.584,0.230,-1.340)

[BAR] // forward lower arm
name=fr_fore_lower posbody=body negbody=fr_spindle pos=(-0.304,-0.148,-1.340) neg=(-0.610,-0.148,-1.340)

[BAR] // rearward lower arm
posbody=body negbody=fr_spindle pos=(-0.256,-0.130,-1.040) neg=(-0.610,-0.148,-1.340)

[BAR] // steering arm (must be named for identification)
name=fr_steering posbody=body negbody=fr_spindle pos=(-0.328,-0.106,-1.467) neg=(-0.584,-0.100,-1.492)

// NASCAR rear suspension geometry:

// We're doing a torque tube instead of the two I-beam arms of NASCAR.  They are
// almost equivalent setups, with the only difference being which part bends.  Since
// the current physics engine doesn't handle bending arms anyway, it doesn't matter.
// We are simulating that aspect through the springs and allowing a full range of
// motion where the torque tube meets the body by using a ball joint.

// The torque tube is connected to the body with a ball joint approximately 100 inches
// in front of the rear axle.
[JOINT]
posbody=body negbody=rear_axle pos=(0.0, -0.07, -0.92)

// Track bar (heights will be changed with track bar adjustments)
[BAR]
posbody=body negbody=rear_axle pos=(-0.55, 0.0, 1.97) neg=(0.55, 0.0, 1.67)

// Rear spindle and wheel connections (axis will be changed with rear camber adjustments)
[JOINT&HINGE]
posbody=rl_wheel negbody=rear_axle pos=rl_wheel axis=(-1.0,0.0,0.0)

[JOINT&HINGE]
posbody=rr_wheel negbody=rear_axle pos=rr_wheel axis=(1.0,0.0,0.0)


